aboutsummaryrefslogtreecommitdiffstats
path: root/actionpack/test/controller/flash_test.rb
diff options
context:
space:
mode:
authorTrevor Turk <trevorturk@gmail.com>2013-04-02 18:41:57 -0500
committerTrevor Turk <trevorturk@gmail.com>2013-04-02 18:41:57 -0500
commit7c7a42734406c4f1d402d32ff0b1b916545d0da0 (patch)
treeba62c423748bb0a606a785e6d558999e55718af0 /actionpack/test/controller/flash_test.rb
parentc959798571b4060b19712e022f4236d75b2b7cfd (diff)
downloadrails-7c7a42734406c4f1d402d32ff0b1b916545d0da0.tar.gz
rails-7c7a42734406c4f1d402d32ff0b1b916545d0da0.tar.bz2
rails-7c7a42734406c4f1d402d32ff0b1b916545d0da0.zip
Rename DummyKeyGenerator -> LegacyKeyGenerator
Diffstat (limited to 'actionpack/test/controller/flash_test.rb')
-rw-r--r--actionpack/test/controller/flash_test.rb4
1 files changed, 2 insertions, 2 deletions
diff --git a/actionpack/test/controller/flash_test.rb b/actionpack/test/controller/flash_test.rb
index 9d4356f546..e4d0eb88db 100644
--- a/actionpack/test/controller/flash_test.rb
+++ b/actionpack/test/controller/flash_test.rb
@@ -1,5 +1,5 @@
require 'abstract_unit'
# FIXME remove DummyKeyGenerator and this require in 4.1
require 'active_support/key_generator'
class FlashTest < ActionController::TestCase
@@ -219,7 +219,7 @@ end
class FlashIntegrationTest < ActionDispatch::IntegrationTest
SessionKey = '_myapp_session'
- Generator = ActiveSupport::DummyKeyGenerator.new('b3c631c314c0bbca50c1b2843150fe33')
+ Generator = ActiveSupport::LegacyKeyGenerator.new('b3c631c314c0bbca50c1b2843150fe33')
class TestController < ActionController::Base
add_flash_types :bar
@@ -1,5 +1,5 @@
require 'abstract_unit'
-# FIXME remove DummyKeyGenerator and this require in 4.1
+# FIXME remove LegacyKeyGenerator and this require in 4.1
require 'active_support/key_generator'
class FlashTest < ActionController::TestCase